---
title: "YAML 配置"
menuText: "YAML 配置"
layout: Doc
---

# YAML 配置

Serverless Framework 通过项目配置文件 `serverless.yml` 完成应用的类型识别与资源配置，本地开发完成后的项目，必须先配置 yml 文件，才可以通过运行 `sls deploy` 命令，将 serverless.yml 中的配置文件和 inputs 中指定参数或代码目录会都被传入 Serverless Components 部署引擎中，从而完成云端部署。

### 基本信息

一个基本的 `serverless.yml` 文件里，第一层配置字段为以下内容：

```yml
#应用组织信息（可选）
app: "" # 应用名称。留空则默认取当前组件的实例名称为app名称。
stage: "" # 环境名称。默认值是 dev。建议使用${env.STAGE}变量定义环境名称

#组件信息
component: scf # (必选) 组件名称，在该实例中为scf
name: scfdemo # (必选) 组件实例名称。

#组件参数配置，根据每个组件，实现具体的资源信息配置
inputs:
```

### 详细配置

接下来在 `inputs` 字段里，根据每个组件创建的云上资源，会进行对应的信息配置，此处以[云函数 SCF 组件](https://github.com/serverless-components/tencent-scf)为例，input 字段内的二级目录如下：

```yml
inputs:
  name: xxx # 云函数名称，默认为 ${name}-${stage}-${app}
  src: ./src # 项目代码路径，默认写法，新建特定命名的 cos bucket 并上传
  handler: index.main_handler #入口
  runtime: Nodejs10.15 # 运行环境 默认 Nodejs10.15
  region: ap-guangzhou # 函数所在区域
  description: This is a function in ${app} application.
  environment: #  环境变量
    variables: #  环境变量对象
      TEST: value
  layers: #layer配置
    - name: scfLayer #  layer名称
      version: 1 #  版本
  events: # 触发器配置
    - timer: # 定时触发器
        parameters:
          cronExpression: "*/5 * * * * * *" # 每5秒触发一次
          enable: true
```

### 全量配置列表

目前 Serverless Framework 各个组件的全量配置信息列表如下：

#### 基础组件

| 组件名称        | 全量配置                                                                                                             |
| --------------- | -------------------------------------------------------------------------------------------------------------------- |
| SCF 组件        | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-scf/blob/master/docs/configure.md)        |
| Website 组件    | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-website/blob/master/docs/configure.md)    |
| API 网关组件    | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-apigateway/blob/master/docs/configure.md) |
| VPC 组件        | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-vpc/blob/master/docs/configure.md)        |
| COS 组件        | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-cos/blob/master/docs/configure.md)        |
| PostgreSQL 组件 | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-postgresql/blob/master/docs/configure.md) |
| CynosDB 组件    | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-cynosdb/blob/master/docs/configure.md)    |
| CDN 组件        | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-cdn/blob/master/example/serverless.yml)   |
| Layer 组件      | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-layer/blob/master/docs/configure.md)      |

#### 框架组件

| 组件名称      | 全量配置                                                                                                           |
| ------------- | ------------------------------------------------------------------------------------------------------------------ |
| Express 组件  | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-express/blob/master/docs/configure.md)  |
| Koa 组件      | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-koa/blob/master/docs/configure.md)      |
| Egg 组件      | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-egg/blob/master/docs/configure.md)      |
| Next.js 组件  | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-nextjs/blob/master/docs/configure.md)   |
| Nuxt.js 组件  | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-nuxtjs/blob/master/docs/configure.md)   |
| Flask 组件    | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-flask/blob/master/docs/configure.md)    |
| Django 组件   | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-django/blob/master/docs/configure.md)   |
| Laravel 组件  | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-laravel/blob/master/docs/configure.md)  |
| ThinkPHP 组件 | [serverless.yml 全量配置](https://github.com/serverless-components/tencent-thinkphp/blob/master/docs/configure.md) |

### 变量引用说明

`serverless.yml` 支持多种方式引用变量

- 顶级参数引用
  在 `inputs` 字段里，支持直接引用顶级配置信息，引用语法如下：`${org}`、`${app}`
- 环境变量引用

  在 `serverless.yml` 中，可以直接通过 `${env}` 的方式，直接引用环境变量配置（包含 .env 文件中的环境变量配置，以及手动配置在环境中的变量参数）

  例如，通过`${env:REGION}`，引用环境变量 REGION

- 引用其它组件输出结果

  如果希望在当前组件配置文件中引用其他组件实例的输出信息，可以通过如下语法进行配置：`${output:[app]:[stage]:[instance name].[output]}`

示例 yml：

```yml
app: demo
component: scf
name: rest-api
stage: dev

inputs:
  name: ${stage}-${app}-${name} # 命名最终为 "dev-demo-rest-api"
  region: ${env:REGION} # 环境变量中指定的 REGION= 信息
  vpcName: ${output:prod:my-app:vpc.name} # 获取其他组件中的输出信息
  vpcName: ${output:${stage}:${app}:vpc.name} # 上述方式也可以组合使用
```

## Stage

由于云上不同服务对环境的概念不同，Serverless Framework 支持通过 `stage` 参数配置，实现多环境模拟，此处以 `Express` 项目为例，示例 `serverless.yml` 文档如下：

```
component: express
name: expressDemo
app: appDemo
stage: test  #想要模拟多环境时，此参数必填，代表不同环境

inputs:
   functionName: expressDemo-${stage} #想要模拟多环境，此参数必填
   src: ./ #需要上传的项目路径
   region: ap-guangzhou
   runtime: Nodejs10.15
   apigatewayConf:
      protocols:
        - http
        - https
      environment: test
      # 该参数为 API 网关产品环境参数，仅支持 test（测试环境）、prepub（预发布环境）和 release（发布环境），建议和 stage 一致
```

除了基本的必填参数之外，为了实现多环境配置，以下参数也是必填的：

1）`stage` 参数：关键参数，规定不同环境

2）`functionName` 参数：函数名称，需要写为 `FunctionName-${stage}` 格式，其中的 `stage` 变量必须引入，如果没这个变量，则不同环境的函数会相互覆盖。

3）`environment`: 是配置云函数的调用 API 环境，仅支持 test（测试环境）、prepub（预发布环境）和 release（发布环境），为方便管理，建议和 stage 一致

完成 yml 配置后，只需更新 `stage` 参数，即可完成应用不同环境的切换。

## 配置描述

主要的参数

参考： https://cloud.tencent.com/document/product/583/18586

| 参数名称       | 必选 | 类型                        | 默认值                                     | 描述                                                                                                                               |
| -------------- | ---- | --------------------------- | ------------------------------------------ | ---------------------------------------------------------------------------------------------------------------------------------- |
| name           | 是   | string                      | `${name}-${stage}-${app}`                  | 创建的函数名称。**云函数名称又是资源 ID，为了保证资源的唯一性，默认采用 `${name}-${stage}-${app}` 变量方式。**                     |
| namespace      | 否   | string                      | `default`                                  | 函数命名空间。云函数旧版本会以命名空间作为环境隔离，SCF 组件保留此参数，但不推荐使用此方式进行隔离。                               |
| src            | 是   | [Src](#Src)                 |                                            | 函数代码路径。如果是对象,配置参数参考                                                                                              |
| handler        | 是   | string                      |                                            | 函数处理方法名称，执行方法表明了调用云函数时需要从哪个文件中的哪个函数开始执行                                                     |
| role           | 否   | string                      |                                            | 云函数绑定的运行角色。                                                                                                             |
| runtime        | 否   | string                      | `Nodejs10.15`                              | 函数运行环境                                                                                                                       |
| region         | 否   | string                      | `ap-guangzhou`                             | 云函数所在区域。详见产品支持的 [地域列表][函数地域列表]。                                                                          |
| description    | 否   | string                      | `This is a function in ${app} application` | 函数描述,最大支持 1000 个英文字母、数字、空格、逗号、换行符和英文句号，支持中文                                                    |
| memorySize     | 否   | number                      | `128`                                      | 函数运行时内存大小，默认为 128M，可选范围 64、128MB-3072MB，并且以 128MB 为阶梯                                                    |
| timeout        | 否   | number                      | `3`                                        | 函数最长执行时间，单位为秒，可选值范围 1-900 秒，默认为 3 秒                                                                       |
| initTimeout    | 否   | number                      | `3`                                        | 函数初始化超时时间，单位为秒，可选值范围 1-30 秒 秒                                                                                |
| eip            | 否   | boolean                     | `false`                                    | 是否[固定出口 IP][固定出口ip]                                                                                                      |
| publicAccess   | 否   | number                      | `true`                                     | 是否开启公网访问                                                                                                                   |
| environment    | 否   | [Environment](#Environment) |                                            | 函数的环境变量，配置参考[环境变量](#环境变量)                                                                                      |
| vpcConfig      | 否   | [Vpc](#Vpc)                 |                                            | 函数的私有网络配置，配置参数参考[私有网络](#私有网络)                                                                              |
| layers         | 否   | [Layer](#Layer)[]           |                                            | 云函数绑定的 layer, 配置参数参考[层配置](#层配置)                                                                                  |
| deadLetter     | 否   | [DeadLetter](#DeadLetter)   |                                            | 死信队列配置，配置参数参考[死信队列](#死信队列)                                                                                    |
| cls            | 否   | [Cls](#Cls)                 |                                            | 函数日志配置，配置参数参考[函数日志](#函数日志)                                                                                    |
| eip            | 否   | boolean                     | `false`                                    | 固定出口 IP。默认为 false，即不启用。                                                                                              |
| asyncRunEnable | 否   | boolean                     | `false`                                    | 是否启用异步执行（长时间运行），默认最大支持 `12小时`，如果配置为 `true`，`cls`（函数日志配置） 必须。此参数只有在函数创建时才有效 |
| traceEnable    | 否   | boolean                     | `false`                                    | 是否启用状态追踪，如果要配置为 `true`，必须配置 `asyncRunEnable` 同时为 `true`                                                     |
| tags           | 否   |                             |                                            | 标签设置。可设置多对 key-value 的键值对                                                                                            |
| cfs            | 否   | [Cfs](#Cfs)                 |                                            | 文件系统挂载配置，用于云函数挂载文件系统。配置参数参考[文件系统](#文件系统)。                                                      |
| events         | 否   | [Event](#Event)[]           |                                            | 触发器配置                                                                                                                         |

**重要字段说明**

- name - 云函数名称，字段字符需满足 `只能包含字母、数字、下划线、连字符，以字母开头，以数字或字母结尾，2~60个字符`
- runtime - 目前仅支持: `Nodejs6.10，Nodejs8.9，Nodejs10.15，Nodejs12.16，Python2.7，Python3.6，PHP5，PHP7，Go1，Java8 和 CustomRuntime`，使用 `CustomRuntime` 部署参考 [CustomRuntime][customruntime]

### Src

代码目录

| 参数名称 | 必选 |   类型   | 默认值 | 描述                                               |
| -------- | :--: | :------: | :----: | :------------------------------------------------- |
| src      |  是  |  string  |        | 代码路径。与 object 不能同时存在。                 |
| exclude  |  否  | string[] |        | 不包含的文件或路径, 遵守 [glob 语法][glob语法参考] |
| bucket   |  否  |  string  |        | 存储桶名称                                         |
| object   |  否  |  string  |        | 部署的代码在存储桶中的路径。                       |

> 注意：如果配置了 `src`，表示部署 `src` 参数指定目录的代码并压缩成 `zip` 后上传到对应的存储桶中；如果配置了 `object`，表示获取对应存储桶中 `object` 对应的代码进行部署

### Environment

环境变量

| 参数名称  | 类型                              | 描述                                      |
| --------- | --------------------------------- | ----------------------------------------- |
| variables | Array of [Variable][函数环境变量] | 环境变量参数，包含多对 key-value 的键值对 |

### Vpc

私有网络

| 参数名称 | 必选 | 类型   | 描述           |
| -------- | ---- | ------ | -------------- |
| vpcId    | 否   | string | 私有网络 的 Id |
| subnetId | 否   | string | 子网的 Id      |

### DeadLetter

死信队列

| 名称       | 必选 | 类型   | 描述                       |
| :--------- | ---- | :----- | :------------------------- |
| Type       | 是   | string | 死信队列模式               |
| Name       | 是   | string | 死信队列名称               |
| FilterType | 否   | string | 死信队列主题模式的标签形式 |

### Layer

层配置

| 参数名称 | 必选 |  类型  | 描述     |
| -------- | :--: | :----: | :------- |
| name     |  是  | string | 层名称   |
| version  |  是  | number | 层版本号 |

### Cls

函数日志

| 参数名称 | 必选 |  类型  | 描述                          |
| -------- | :--: | :----: | :---------------------------- |
| logsetId |  否  | string | 函数日志投递到的 CLS LogsetID |
| topicId  |  否  | string | 函数日志投递到的 CLS TopicID  |

### Cfs

文件系统，使用文件系统必须配置[私有网络](#私有网络)，并保证 cfs 文件系统与云函数在同一个私有网络下。

| 参数名称       | 必选 |  类型  | 描述              |
| -------------- | :--: | :----: | :---------------- |
| cfsId          |  是  | String | 文件系统实例 id   |
| mountInsId     |  是  | String | 文件系统挂载点 id |
| localMountDir  |  是  | String | 本地挂载点        |
| remoteMountDir |  是  | String | 远程挂载点        |

### Event

触发器，触发器配置为数组，按照配置的 name 和 param 创建触发器。

支持以下触发器：

```
timer - 定时触发器
apigw - API 网关触发器
cos - COS 触发器
cmq - CMQ 主题订阅触发器
ckafka - CKafka 触发器
cls - CLS 触发器
mps - MPS 触发器
clb - CLB 触发器
```

> **注意**：对于 `API 网关触发器`，如果没有配置 网关服务 ID （serviceId），则自动创建一个 API 网关服务，对于其他触发器仅执行配置触发器，不涉及服务资源创建。

| 参数名称   | 必选 |  类型  |                默认值                | 描述                                   |
| ---------- | :--: | :----: | :----------------------------------: | :------------------------------------- |
| parameters |  是  | object |                                      | 根据触发器类型，参考以下触发器参数表。 |
| name       |  否  | string | `触发器类型-${name}-${stage}-${app}` | 触发器名称。                           |

参考 [官方触发器配置描述](https://cloud.tencent.com/document/product/583/39901)

#### 定时触发器

参考： https://cloud.tencent.com/document/product/583/9708

| 参数名称       | 必选 |  类型   |   默认值   | 描述                                             |
| -------------- | :--: | :-----: | :--------: | :----------------------------------------------- |
| qualifier      |  否  | string  | `$DEFAULT` | 触发版本，默认为 `$DEFAULT`，即 `默认流量`       |
| cronExpression |  是  | number  |            | 触发时间，为 [Cron][定时触发器-cron表达式]表达式 |
| argument       |  否  | object  |            | 入参参数。                                       |
| enable         |  否  | boolean |  `false`   | 触发器是否启用                                   |

#### COS 触发器

参考： https://cloud.tencent.com/document/product/583/9707

| 参数名称  | 必选 |           类型           |   默认值   | 描述                                               |
| --------- | :--: | :----------------------: | :--------: | :------------------------------------------------- |
| qualifier |  否  |          string          | `$DEFAULT` | 触发版本，默认为 `$DEFAULT`，即 `默认流量`         |
| bucket    |  是  |          string          |            | 配置的 COS Bucket，仅支持选择同地域下的 COS 存储桶 |
| filter    |  是  | [CosFilter][cos过滤规则] |            | COS 文件名的过滤规则                               |
| events    |  是  |          string          |            | [COS 的事件类型][cos事件类型]                      |
| enable    |  否  |         boolean          |  `false`   | 触发器是否启用                                     |

#### CMQ 触发器

| 参数名称   | 必选 | 类型     | 默认值     | 描述                                                                         |
| ---------- | ---- | -------- | ---------- | :--------------------------------------------------------------------------- |
| qualifier  | 否   | string   | `$DEFAULT` | 触发版本，默认为 `$DEFAULT`，即 `默认流量`                                   |
| name       | 是   | string   |            | CMQ Topic 主题队列名称                                                       |
| filterType | 否   | number   |            | 消息过滤类型，1 为标签类型，2 为路由匹配类型                                 |
| filterKey  | 否   | string[] |            | 当 filterType 为 1 时表示消息过滤标签，当 filterType 为 2 时表示 Binding Key |
| enable     | 否   | boolean  | `false`    | 触发器是否启用                                                               |

> 注意：添加 CMQ 触发器，需要给 `SLS_QcsRole` 添加 `QcloudCMQFullAccess` 策略。

#### Ckafka 触发器

| 参数名称  | 必选 | 类型    | 默认值     | 描述                                                       |
| --------- | ---- | ------- | ---------- | :--------------------------------------------------------- |
| qualifier | 否   | string  | `$DEFAULT` | 触发版本，默认为 `$DEFAULT`，即 `默认流量`                 |
| name      | 是   | string  |            | 配置连接的 CKafka 实例，仅支持选择同地域下的实例。         |
| topic     | 是   | string  |            | 支持在 CKafka 实例中已经创建的 Topic。                     |
| maxMsgNum | 是   | number  |            | 5 秒内每汇聚 maxMsgNum 条 Ckafka 消息，则触发一次函数调用  |
| offset    | 是   | string  |            | offset 为开始消费 Ckafka 消息的位置，目前只能填写 `latest` |
| retry     | 是   | number  |            | 重试次数，函数调用失败时的最大重试次数。                   |
| enable    | 否   | boolean | `false`    | 触发器是否启用                                             |

> 注意：添加 CKafka 触发器，需要给 `SLS_QcsRole` 添加 `QcloudCKafkaFullAccess` 策略。

#### API 网关触发器

| 参数名称    | 必选 |   类型   | 默认值      | 描述                                                                           |
| ----------- | ---- | :------: | :---------- | :----------------------------------------------------------------------------- |
| environment | 否   |  string  | `release`   | 发布的环境，填写 `release`、`test` 或 `prepub`，不填写默认为`release`          |
| serviceId   | 否   |  string  |             | 网关 Service ID（不传入则新建一个 Service）                                    |
| protocols   | 否   | string[] | `['http']`  | 前端请求的类型，如 http，https，http 与 https                                  |
| netTypes    | 否   | string[] | `['OUTER']` | 网络类型，如 `['OUTER']`, `['INNER']` 与`['OUTER', 'INNER']`                   |
| serviceName | 否   |  string  |             | 网关 API 名称。如果不传递则默认新建一个名称与触发器名称相同的 Apigw API 名称。 |
| description | 否   |  string  |             | 网关 API 描述                                                                  |
| endpoints   | 是   | object[] |             | 参考 [endpoint](#endpoints-参数) 参数。                                        |

> 注意：如果配置多个 API 网关触发器，需要配置不同的 `serviceName`

##### endpoints 参数

参考： https://cloud.tencent.com/document/product/628/14886

| 参数名称                  | 必选 |            类型             | 默认值  | 描述                                                                                                      |
| ------------------------- | ---- | :-------------------------: | :------ | :-------------------------------------------------------------------------------------------------------- |
| path                      | 是   |           string            |         | API 的前端路径，如/path。                                                                                 |
| method                    | 否   |           string            |         | API 的前端请求方法，如 GET                                                                                |
| apiId                     | 否   |           string            |         | API ID。如果不传递则根据 path 和 method 创建一个，传递了直接忽略 path 和 method 参数。                    |
| apiName                   | 否   |           string            |         | API 名称                                                                                                  |
| description               | 否   |           string            |         | API 描述                                                                                                  |
| enableCORS                | 是   |           boolean           | `false` | 是否需要开启跨域                                                                                          |
| responseType              | 否   |           string            |         | 自定义响应配置返回类型，现在只支持 HTML、JSON、TEST、BINARY、XML（此配置仅用于生成 API 文档提示调用者）。 |
| serviceTimeout            | 是   |           number            | `15`    | API 的后端服务超时时间，单位是秒。                                                                        |
| param                     | 否   |   [Parameter](#Parameter)   |         | 前端参数                                                                                                  |
| function                  | 否   |    [Function](#Function)    |         | SCF 配置                                                                                                  |
| usagePlan                 | 否   |   [UsagePlan](#UsagePlan)   |         | 使用计划                                                                                                  |
| auth                      | 否   |        [Auth](#Auth)        |         | API 密钥配置                                                                                              |
| isBase64Encoded           | 否   |           boolean           | `false` | 是否开启 Base64 编码，只有后端为 scf 时才会生效                                                           |
| isBase64Trigger           | 否   |           boolean           | `false` | 是否开启 Base64 编码的 header 触发，只有后端为 scf 时才会生效                                             |
| base64EncodedTriggerRules | 否   | [Base64Rule](#Base64Rule)[] | []      | Header 触发 Base64 编码规则，总规则数不能超过 10，只有 `isBase64Trigger` 设置为 `true` 才有效             |

###### Parameter

前端参数

| 参数名称     | 必选 | 类型    | 默认值 | 描述                                                      |
| ------------ | ---- | ------- | ------ | --------------------------------------------------------- |
| name         | 否   | string  |        | API 的前端参数名称。                                      |
| position     | 否   | string  |        | API 的前端参数位置。当前仅支持 PATH、QUERY、HEADER        |
| required     | 否   | boolean |        | API 的前端参数是否必填，true：表示必填，false：表示可选。 |
| type         | 否   | string  |        | API 的前端参数类型，如 String、Int 等。                   |
| defaultValue | 否   | string  |        | API 的前端参数默认值。                                    |
| desc         | 否   | string  |        | API 的前端参数备注。                                      |

###### Function

SCF 配置

| 参数名称             | 必选 | 类型    | 默认值     | 描述                     |
| -------------------- | ---- | ------- | ---------- | ------------------------ |
| isIntegratedResponse | 否   | boolean | `false`    | 是否启用 SCF 集成响应。  |
| functionQualifier    | 否   | string  | `$DEFAULT` | 触发器关联的 SCF 版本 。 |

###### UsagePlan

使用计划

参考: https://cloud.tencent.com/document/product/628/14947

| 参数名称      | 必选 | 类型   | 描述                                                    |
| ------------- | :--: | ------ | :------------------------------------------------------ |
| usagePlanId   |  否  | string | 用户自定义使用计划 ID                                   |
| usagePlanName |  否  | string | 用户自定义的使用计划名称                                |
| usagePlanDesc |  否  | string | 用户自定义的使用计划描述                                |
| maxRequestNum |  否  | number | 请求配额总数，如果为空，将使用-1 作为默认值，表示不开启 |

###### Auth

API 密钥配置

参考: https://cloud.tencent.com/document/product/628/14916

| 参数名称   | 类型   | 描述     |
| ---------- | :----- | :------- |
| secretName | string | 密钥名称 |
| secretIds  | string | 密钥 ID  |

###### Base64Rule

Header 触发 Base64 编码规则，总规则数不能超过 10，只有 `isBase64Trigger` 设置为 `true` 才有效

参考: https://tcloud-dev.oa.com/document/product/628/16924?!preview&preview_docmenu=1&lang=cn&!document=1#Base64EncodedTriggerRule

| 参数名称 | 类型     | 描述                                                                                                                                          |
| -------- | :------- | :-------------------------------------------------------------------------------------------------------------------------------------------- |
| name     | string   | 进行编码触发的 header，可选值 "Accept"和"Content_Type" 对应实际数据流请求 header 中的 Accept 和 Content-Type                                  |
| value    | string[] | 进行编码触发的 header 的可选值数组, 数组元素的字符串最大长度为 40，元素可以包括数字，英文字母以及特殊字符，特殊字符的可选值为： . + \* - / \_ |

例如 `value` 可以配置为：

```yaml
value:
  - application/zip
```

#### CLS 触发器

| 参数名称  | 必选 | 类型    | 默认值     | 描述                                       |
| --------- | ---- | ------- | ---------- | :----------------------------------------- |
| qualifier | 否   | string  | `$DEFAULT` | 触发版本，默认为 `$DEFAULT`，即 `默认流量` |
| topicId   | 是   | string  |            | CLS 日志主题 ID                            |
| maxWait   | 否   | number  | `60`       | 最长等待时间，单位秒                       |
| enable    | 否   | boolean | `false`    | 触发器是否启用                             |

> 注意：添加 CLS 触发器，需要给 `SLS_QcsRole` 添加 `QcloudCLSFullAccess` 策略。

#### MPS 触发器

| 参数名称  | 必选 | 类型    | 默认值     | 描述                                                                  |
| --------- | ---- | ------- | ---------- | :-------------------------------------------------------------------- |
| qualifier | 否   | string  | `$DEFAULT` | 触发版本，默认为 `$DEFAULT`，即 `默认流量`                            |
| type      | 是   | string  |            | 事件类型。`WorkflowTask - 工作流任务`，`EditMediaTask - 视频编辑任务` |
| enable    | 否   | boolean | `false`    | 触发器是否启用                                                        |

> 注意：添加 MPS 触发器，需要给 `SLS_QcsRole` 添加 `QcloudMPSFullAccess` 策略。

## 关于 API 网关 Base64 编码

> 注意：开启 API 网关 Base64 编码的后端必须是 `云函数`

如果需要开启 API 网关 Base64 编码，必须配置 `isBase64Encoded` 为 `true`，此时每次请求的请求内容都会被 Base64 编码后再传递给云函数。如果想要部分请求 Base64 编码，可以通过配置 `isBase64Trigger` 为 `true`，配置 `base64EncodedTriggerRules` Header 触发规则，此时 API 网关将根据触发规则对请求头进行校验，只有拥有特定 Content-Type 或 Accept 请求头的请求会被 Base64 编码后再传递给云函数，不满足条件的请求将不进行 Base64 编码，直接传递给云函数。
官方介绍文档：https://cloud.tencent.com/document/product/628/51799

<!-- Refer links -->

[函数角色与授权]: https://cloud.tencent.com/document/product/583/32389#.E8.A7.92.E8.89.B2.E8.AF.A6.E6.83.85
[函数地域列表]: https://cloud.tencent.com/document/api/583/17238#.E5.9C.B0.E5.9F.9F.E5.88.97.E8.A1.A8
[glob语法参考]: https://github.com/isaacs/node-glob
[函数环境变量]: https://cloud.tencent.com/document/api/583/17244#Variable
[定时触发器-cron表达式]: https://cloud.tencent.com/document/product/583/9708#cron-.E8.A1.A8.E8.BE.BE.E5.BC.8F
[cos过滤规则]: https://cloud.tencent.com/document/product/583/39901#CosFilter
[cos事件类型]: https://cloud.tencent.com/document/product/583/9707#cos-.E8.A7.A6.E5.8F.91.E5.99.A8.E5.B1.9E.E6.80.A7
[固定出口ip]: https://cloud.tencent.com/document/product/583/38198
[customruntime]: https://cloud.tencent.com/document/product/583/47274
[clb重定向配置]: https://cloud.tencent.com/document/product/214/8839
